﻿/**
 * @fileoverview 開いているドキュメントのタグを一旦解除し、PDF保存してからアンドゥする
 * @author Kenshi Muto &lt;kmuto@debian.org&gt;
 * @requires libCommon.jsx
*/

/*
    Copyright:
    2012 Kenshi Muto <kmuto@debian.org>
----------------------------------------------------------------------
ソフトウェア使用許諾同意書
本ソフトウェアの利用・変更・再配布にあたっては、下記の使用許諾同意書に
同意する必要があります。

1. 本使用許諾同意書における「ソフトウェア」とは、機械可読の資料 (ライブ
   ラリ、スクリプト、ソースファイル、データファイル)、実行形式、および
   文書を意味します。
2. 本ソフトウェアの使用許諾同意書に同意する限りにおいて、使用者は
   本ソフトウェアを自由に利用、変更することができます。
3. 本ソフトウェアに変更を加えない限りにおいて、使用者は本ソフトウェアを
   自由にコピー、再配布することができます。
4. 本ソフトウェアは無保証です。作者およびそれに関連する組織、配布者は、
   本ソフトウェアの使用に起因する一切の直接損害、間接損害、偶発的損害、
   特別損害、懲戒的損害、派生的損害について何らの責任・保証も負いません。
5. 本ソフトウェアを変更した上で再配布するときには、下記の事項すべてに
   従わなければなりません。
   - 使用許諾同意書の内容に変更を加えてはなりません。技術上の理由で
     文字エンコーディングの変換を行うことは許可しますが、その使用者が
     特殊な技術的措置なしに可読な形でなければなりません。
   - 技術上の理由でバイナリ化・難読化を行う場合も、変更箇所を含めた
     ソフトウェアを、その使用者が可読可能な形式の形で同一のメディアで
     提供しなければなりません。本使用許諾同意書の2条および3条により、
     使用者が可読形式の該当ソフトウェアを変更、コピー、再配布することを
     妨げてはなりません。
   - ソフトウェア構成物の所定の作者名の欄に、変更者のクレジット
     (個人名、企業名、所属、連絡先など)を「追加」しなければなりません。
6. 本ソフトウェアを変更した上で再配布するときには、変更理由および
   その内容を明記することが推奨されます。
7. 使用者がソフトウェアに適用可能な特許に対して特許侵害にかかわる何らか
   の行動を開始した時点で、この使用許諾同意書は自動的に終了し、以降
   使用者はこの使用許諾書によって与えられた一切の権利を放棄するものと
   します。

著作権所有者 Copyright (C) 2012 Kenshi Muto. All rights reserved.
使用許諾同意書バージョン1.0
著作権所有者による書面での事前の許可がない限り、この使用許諾同意書
に変更を加えてはなりません。
----------------------------------------------------------------------
*/
#include "../libs/libCommon.jsx"

var defaultpresetname = "INDD_PDF+X-1a2001"; // デフォルトにしたいプリセット名

var myDocument = app.activeDocument;
// プリセットダイアログ
var defaultpreset = 0;
var wObj = app.dialogs.add({ name: "タグなしPDFの出力" });
var pdfpresets = new Array(), pspresets = new Array();
for (var i = 0; i < app.pdfExportPresets.length; i++) {
  pdfpresets[i] = app.pdfExportPresets.item(i).name;
  if (pdfpresets[i] == defaultpresetname) {
    defaultpreset = i; //TODO:たくさんあると面倒なので、選択ツールを作るべきか
  }
}

var pdflist;
/* PDFプリセットの指定はダイアログ表示だと意味がないみたい……コメントアウトする
with (wObj.dialogColumns.add(wObj.dialogColumns.add())) {
  with (dialogRows.add()) {
    staticTexts.add({staticLabel: "PDFプリセット", minWidth: 120});
    pdflist = dropdowns.add({stringList:pdfpresets, selectedIndex: defaultpreset});
  }
}
if (wObj.show() == false) exit(0);
*/

// PDFファイルの保存
var loop =true; // 上書き質問のためのループ
do {
  // PDF保存パスを探索
  var pathes = new Folder(myDocument.filePath.parent).getFiles("*-PDF");
  var docObj;
  if (pathes.length > 0) {
    // PDFパスにドキュメントファイルの.inddを-.pdfに変えてファイル名候補にする
    docObj = new File(pathes[0] + "/" + myDocument.name.replace(/\.indd$/, "-.pdf"));
  } else {
    // 現在のドキュメントファイルパスの.inddを-.pdfに変えてファイル名候補にする
    docObj = new File((myDocument.fullName + "").replace(/\.indd$/, "-.pdf"));
  }

var filename = docObj.saveDlg("PDFファイルの保存", "PDF:*.pdf,すべてのファイル:*.*");
  if (filename) {
    var fileObj = new File(filename);
    /* if (fileObj.exists == true) { // 上書き確認はsaveDlgで行われる
      var wObj = app.dialogs.add({ name: "ファイルが存在します" });
      var wtmp = wObj.dialogColumns.add();
      wtmp.staticTexts.add({staticLabel: filename + " はすでに存在します。上書きしますか?"});
      if (wObj.show() == false) continue;
    } */

    var tag = false;
    if (myDocument.xmlElements.length > 0&& myDocument.xmlElements[0].xmlElements.length > 0) {
      // XML要素があるときにはタグ解除
      if (getCSVersion() > 3) {
        myDocument.xmlElements.item(0).xmlElements.everyItem().untag(); // CS5.5ではこうしないとだめ
      } else {
        myDocument.xmlElements.item(0).untag();
      }
      tag = true;
    }

    try {
      // PDFファイルの保存。3つめのtrueはページ指定などのウィンドウを開くためのオプションフラグ
      // コメントアウトした myDocument.exportFile(ExportFormat.PDF_TYPE, fileObj, true, app.pdfExportPresets.item(pdflist.stringList[pdflist.selectedIndex]));
      myDocument.exportFile(ExportFormat.PDF_TYPE, fileObj, true, app.pdfExportPresets.item(0)); // プリセットの意味が出ないので0にした
    } finally {
      if (tag) {
        // 解除作業をundo。安全なはずだが……
        myDocument.undo(); // 大丈夫か?
      }
    }
    loop = false;
  } else {
    loop = false;
  }
} while (loop == true);
